************************
Authors and contributors
************************

The following people have contributed code and/or ideas to the current version
of Elephant. The institutional affiliations are those at the time of the
contribution, and may not be the current affiliation of a contributor.

* Alper Yegenoglu [1]
* Andrew Davison [2]
* Björn Müller [1]
* Detlef Holstein [2]
* Eilif Muller [3, 4]
* Emiliano Torre [1]
* Espen Hagen [1]
* Jeffrey Gill [11]
* Jan Gosmann [6, 8]
* Julia Sprenger [1]
* Junji Ito [1]
* Michael Denker [1]
* Paul Chorley [1]
* Pierre Yger [2]
* Pietro Quaglio [1]
* Richard Meyes [1]
* Vahid Rostami [1]
* Subhasis Ray [5]
* Robert Pröpper [6]
* Richard C Gerkin [7]
* Bartosz Telenczuk [2]
* Chaitanya Chintaluri [9]
* Michał Czerwiński [9]
* Michael von Papen [1]
* Robin Gutzen [1]
* Felipe Méndez [10]
* Simon Essink [1]
* Alessandra Stella [1]
* Peter Bouss [1]
* Alexander van Meegen [1]
* Aitor Morales-Gregorio [1]
* Cristiano Köhler [1]
* Paulina Dąbrowska [1]
* Jan Lewen [1]
* Alexander Kleinjohann [1]
* Danylo Ulianych [1]
* Anno Kurth [1]
* Regimantas Jurkus [1]
* Philipp Steigerwald [12]
* Manuel Ciba [12]
* Maximilian Kramer [1]
* Florian Porrmann [13]
* Sarah Pilz [13]

1. Institute of Neuroscience and Medicine (INM-6) and Institute for Advanced Simulation (IAS-6) and JARA-Institute Brain Structure-Function Relationships (INM-10), Jülich Research Centre, Jülich, Germany
2. Unité de Neurosciences, Information et Complexité, CNRS UPR 3293, Gif-sur-Yvette, France
3. Electronic Visions Group, Kirchhoff-Institute for Physics, University of Heidelberg, Germany
4. Brain-Mind Institute, Ecole Polytechnique Fédérale de Lausanne, Switzerland
5. NIH–NICHD, Laboratory of Cellular and Synaptic Physiology, Bethesda, Maryland 20892, USA
6. Neural Information Processing Group, Institute of Software Engineering and Theoretical Computer Science, Technische Universität Berlin, Germany
7. Arizona State University School of Life Sciences, USA
8. Computational Neuroscience Research Group (CNRG), Waterloo Centre for Theoretical Neuroscience, Waterloo, Canada
9. Nencki Institute of Experimental Biology, Warsaw, Poland
10. Instituto de Neurobiología, Universidad Nacional Autónoma de México, Mexico City, Mexico
11. Case Western Reserve University (CWRU), Cleveland, OH, USA
12. BioMEMS Lab, TH Aschaffenburg University of applied sciences, Germany
13. Cognitronics and Sensor Systems, CITEC, Bielefeld University, Bielefeld, Germany

If we've somehow missed you off the list we're very sorry - please let us know.
